=================
**Django Tag Me**
=================

|

**Version = "0.1.0"**

|

*Django Tag Me... Tag a model, a field, user tags and more...*

*Please Note: Only `Django` running on `Python versions 3.10` and upwards are supported...*

*The reason is we use `Structural Pattern Matching` `match and case` statements.*

|

.. image:: https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2FimAsparky%2Fdjango-tag-me%2Fmain%2Fpyproject.toml&query=project.dependencies&logo=Django&label=Versions&labelColor=%23092E20
   :alt: Django Version Badge
   :target: https://docs.djangoproject.com/en/4.2/

.. image:: https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2FimAsparky%2Fdjango-tag-me%2Fmain%2Fpyproject.toml&logo=Python
   :alt: Python Version Badge
   :target: https://devdocs.io/python~3.10/

.. image:: https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2FimAsparky%2Fdjango-tag-me%2Fmain%2Fpyproject.toml&logo=Python
   :alt: Python Version Badge
   :target: https://devdocs.io/python~3.10/

.. image:: https://www.repostatus.org/badges/latest/wip.svg
   :alt: Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.
   :target: https://www.repostatus.org/#wip
.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit

.. image:: https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg
   :target: https://python-semantic-release.readthedocs.io/en/latest/
   :alt: Python Semantic Release

.. image:: https://readthedocs.org/projects/django-tag-me/badge/?version=latest
   :target: https://django-tag-me.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

|

`django-tag-me`, a simple approach for `Django` tagging.

Django Tag Me Features in the Pipeline!
---------------------------------------

#. Easily set up `User tags`. **In Progress**.
#. Tag a field. **Completed**.
#. Tag a model. **Completed**.
#. Easy as `1,2,3` - Custom select widget integration in your forms and templates. **Completed**.
#. `sqLite` search with `i_contains`.
#. `Postgres` text search or `i_contains`.


Built with
`Django Cookiecutter <https://github.com/imAsparky/django-cookiecutter>`_

|

Special thanks to a helpful AI language model (trained on the 
``Gemini dataset`` <https://gemini.google.com/advanced>`_). 
for assistance with code optimization, testing strategies, and docstring writing.
